@@ -6,7 +6,7 @@ Rubric::User - a Rubric user
 
 =head1 VERSION
 
- $Id: User.pm,v 1.11 2004/12/02 04:07:43 rjbs Exp $
+ $Id: User.pm,v 1.17 2004/12/07 14:40:47 rjbs Exp $
 
 =head1 DESCRIPTION
 
@@ -26,11 +26,16 @@ __PACKAGE__->table('users');
  username - the user's login name
  password - the hex md5sum of the user's password
  email    - the user's email address
- validation_code - the code sent to the user for validation; NULL if validated
+ created  - the user's date of registration
+
+ verification_code - the code sent to the user for verification
+                     NULL if verified
 
 =cut
 
-__PACKAGE__->columns(All => qw(username password email validation_code));
+__PACKAGE__->columns(
+	All => qw(username password email created verification_code)
+);
 
 =head1 RELATIONSHIPS
 
@@ -146,6 +151,24 @@ sub related_tags_counted {
 	my $result = $self->db_Main->selectall_arrayref($query, undef, $self);
 }
 
+=head1 INFLATIONS
+
+=head2 created
+
+The created column is stored as seconds since epoch, but inflated to
+Time::Piece objects.
+
+=cut
+
+__PACKAGE__->has_a(created => 'Time::Piece', deflate => 'epoch');
+
+__PACKAGE__->add_trigger(before_create => \&create_times);
+
+sub create_times {
+	my $self = shift;
+	$self->created(scalar gmtime) unless $self->{created};
+}
+
 =head1 METHODS
 
 =head2 quick_entry(\%entry)
@@ -191,6 +214,26 @@ sub quick_entry {
 	return $entry;
 }
 
+=head2 verify($code)
+
+If the given code matches this user's C<verification_code>, the user will be
+verified; that is, his C<verification_code> will be undefined.
+
+=cut
+
+sub verify {
+	my ($self, $code) = @_;
+
+	return unless $self->verification_code;
+
+	if ($code and $code eq $self->verification_code) {
+		$self->verification_code(undef);
+		$self->update;
+		return 1;
+	}
+	return;
+}
+
 =head1 TODO
 
 =head1 AUTHOR
